import { Vector } from "./vector";
import { AABB } from "./aabb";
import { Curve } from "./curve";
export declare class Arc implements Curve {
    c: Vector;
    r: number;
    startAngle: number;
    endAngle: number;
    constructor(center: Vector, r: number, startAngle?: number, endAngle?: number);
    get sweep(): number;
    /**
     * Get start point of arc
     * @returns {Point}
     */
    get start(): Vector;
    /**
     * Get end point of arc
     * @returns {Point}
     */
    get end(): Vector;
    get vertices(): Vector[];
    /**
     * Get arc length
     * @returns {number}
     */
    get length(): number;
    clone(): Arc;
    /**
     * Returns true if arc contains point, false otherwise
     * @param {Point} pt - point to test
     * @returns {boolean}
     */
    contains(pt: Vector): boolean;
    /**
     * Get bounding box of the arc
     * @returns {AABB}
     */
    getAABB(): AABB;
    /**
     * Breaks arc in extreme point 0, pi/2, pi, 3*pi/2 and returns array of sub-arcs
     * @returns {Arcs[]}
     */
    protected breakToFunctional(): Array<Arc>;
}
