import { AABB } from '../aabb';
declare class LQTreeElement<T> {
    aabb: AABB;
    data: T;
    constructor(aabb: AABB, data: T);
}
declare class LQTreeNode<T> {
    children: [LQTreeNode<T>, LQTreeNode<T>, LQTreeNode<T>, LQTreeNode<T>] | null;
    baseBound: AABB;
    count: number;
    looseBound: AABB;
    protected elements: Array<LQTreeElement<T>>;
    constructor(minX: number, minY: number, maxX: number, maxY: number);
    extendLooseBound(result: AABB): void;
    contains(aabb: AABB): boolean;
    intersects(aabb: AABB): boolean;
    getRegion(aabb: AABB): number;
    addElement(element: LQTreeElement<T>): void;
    recalcBound(): void;
    get elementCount(): number;
    getElements(): LQTreeElement<T>[];
    removeElement(element: LQTreeElement<T>): boolean;
    clearElements(): void;
    toString(indentNum?: number): string;
    toCanvasParameter(aabb: AABB): string;
    toCanvasDraw(): string;
}
/**
 * Loose QuadTree
 */
export declare class LQTree<T> {
    readonly maxChildren: number;
    readonly maxLayer: number;
    root: LQTreeNode<T>;
    idGenerator: number;
    protected elementMap: Map<number, LQTreeElement<T>>;
    constructor(width: number, height: number, maxChildren?: number, maxLayer?: number);
    insert(aabb: AABB, data: T): number;
    protected insertNode(node: LQTreeNode<T>, element: LQTreeElement<T>, layer: number): void;
    split(node: LQTreeNode<T>, layer: number): void;
    delete(id: number): boolean;
    protected deleteInNode(node: LQTreeNode<T>, element: LQTreeElement<T>): boolean;
    getAll(query: AABB, result: Array<T>): Array<T>;
    search(query: AABB, callBack: (data: T) => boolean): void;
    protected searchNode(node: LQTreeNode<T>, query: AABB, callBack: (data: T) => boolean): boolean;
    toString(): string;
    toCanvasDraw(): string;
}
export {};
