export interface GraphNode {
    astar: AStarNode;
    weight: number;
    getCost(fromNeighbor: GraphNode): number;
    isWall(): boolean;
    neighbors(): Array<GraphNode>;
}
export declare class AStarNode {
    node: GraphNode;
    f: number;
    g: number;
    h: number;
    visited: boolean;
    closed: boolean;
    parent: AStarNode | null;
    constructor(graphNode: GraphNode);
    clean(): void;
}
/**
 * Graph for javascript-astar. It implements the functionality for astar. See GPS test from astar
 * repo for structure: https://github.com/bgrins/javascript-astar/blob/master/test/tests.js
 *
 * @class NavGraph
 * @private
 */
export declare class NavGraph {
    private nodes;
    private dirtyNodes;
    private heuristic;
    constructor(nodes: Array<GraphNode>, navHeuristic: (n1: GraphNode, n2: GraphNode) => number);
    cleanDirty(): void;
    markDirty(node: AStarNode): void;
    destroy(): void;
    static pathTo(node: AStarNode): AStarNode[];
    /**
     * Perform an A* Search on a graph given a start and end node.
     * @param {Graph} graph
     * @param {GridNode} start
     * @param {GridNode} end
     * @param {Object} [options]
     * @param {bool} [options.closest] Specifies whether to return the
     path to the closest node if the target is unreachable.
     * @param {Function} [options.heuristic] Heuristic function (see
     *          astar.heuristics).
     */
    search(startNode: GraphNode, endNode: GraphNode): AStarNode[];
}
