import { ConvexShape } from "./convex-shape";
import { Vector } from "./vector";
import { AABB } from "./aabb";
import { Transform } from "./transform";
import { Segment } from "./segment";
import { CollisionResult } from "./collision/collision-result";
/**
 * Polygon in this class satisfies:
 * 1. It must be a simple polygon.
 * 2. It contain the point (0, 0).
 * 3. Points are sorted in counter-clockwise order from it's center.
 */
export declare class Polygon implements ConvexShape {
    transform: Transform;
    protected points: Array<Vector>;
    calcPoints: Array<Vector>;
    centroid: Vector;
    constructor(pos: Vector, points: Array<Vector>);
    static fromAABB(aabb: AABB): Polygon;
    get originPoints(): Vector[];
    rotate(angle: number, center?: Vector): this;
    translate(x: number, y: number): this;
    rotateLocal(angle: number, center?: Vector): void;
    translateLocal(x: number, y: number): this;
    recalc(): this;
    getOrigin(): Vector;
    getCentroid(): Vector;
    intersectsSegment(line: Segment, result?: CollisionResult): boolean;
    intersects(shape: ConvexShape, result?: CollisionResult): boolean;
    isPointIn(v: Vector): boolean;
    isPointOn(v: Vector): boolean;
    getAABB(): AABB;
    getOriginAABB(): AABB;
    static getAABBFromPoints(points: Array<Vector>): AABB;
    getArea(): number;
    toCanvasDraw(scale?: number): string;
    private getFarthestIndexInDirection;
    getFarthestPointInDirection(d: Vector): Vector;
    getFarthestEdgeInDirection(d: Vector): Segment;
    validate(): boolean;
    recenter(): void;
}
