import { Vector } from "./vector";
import { AABB } from "./aabb";
import { Curve } from "./curve";
export declare enum VORONOI_REGION {
    LEFT = 0,
    UP = 1,
    DOWN = 2,
    RIGHT = 3
}
export declare class Segment implements Curve {
    v1: Vector;
    v2: Vector;
    constructor(v1: Vector, v2: Vector);
    getAABB(): AABB;
    contains(v: Vector): boolean;
    isPointOnLine(p: Vector, tolerance?: number): boolean;
    cross(p: Vector): number;
    dot(dir: Vector): number;
    /**
    * Calculates which Voronoi region a point is on a line segment.
    * It is assumed that both the line and the point are relative to `(0,0)`
    *
    *            |       (1)      |
    *     (0)  [S]--------------[E]  (3)
    *            |       (2)      |
    * @param {Vector} point The point.
    * @return  {VORONOI_REGION} VORONOI_REGION.LEFT (0) if it is the left region,
    *          VORONOI_REGION.UP (1) if it is the up region,
    *          VORONOI_REGION.DOWN (2) if it is the down region.
    *          VORONOI_REGION.RIGHT (3) if it is the right region.
    */
    voronoiRegion(point: Vector): VORONOI_REGION;
    len2(): number;
    len(): number;
    lerp(t: number): Vector;
    intersects(segment: Segment): boolean;
}
