import { Vector } from "./vector";
export declare class Transform {
    /** the cosine of the rotation angle */
    protected cost: number;
    /** the sine of the rotation angle */
    protected sint: number;
    /** The x,y translation */
    _pos: Vector;
    constructor(transform?: Transform | Vector);
    /**
     * Internal helper method to rotate this {@link Transform} by an angle &thetasym; around a point
     * @param theta theta
     * @param x the x coordinate of the point
     * @param y the y coordinate of the point
     * @since 3.3.1
     */
    rotate(theta: number, x: number, y: number): void;
    set angle(theta: number);
    /**
     * Returns the rotation.
     * @return double angle in the range [-&pi;, &pi;]
     */
    get angle(): number;
    set position(pos: Vector);
    get position(): Vector;
    get x(): number;
    get y(): number;
    translate(x: number, y: number): void;
    transform(vector: Vector, tv: Vector): Vector;
    inverseTransform(vector: Vector, tv: Vector): Vector;
    /**
     * Sets this transform to the given transform.
     * @param transform the transform to copy
     */
    set(transform: Transform): this;
    mulTransform(transform: Transform): this;
    inverse(): this;
    mulInverseTransform(transform: Transform): this;
    clone(): Transform;
    /**
     * Interpolates linearly by alpha towards the given end transform placing
     * the result in the given transform.
     * <p>
     * Interpolating from one angle to another can have two results depending on the
     * direction of the rotation.  If a rotation was from 30 to 200 the rotation could
     * be 170 or -190.  This interpolation method will always choose the smallest
     * rotation (regardless of sign) as the rotation direction.
     * @param end the end transform
     * @param alpha the amount to interpolate
     * @param result the transform to place the result
     * @since 1.2.0
     */
    lerp(end: Transform, alpha: number, result: Transform): void;
    toString(): string;
}
