import { Polygon } from "./polygon";
import { Vector } from "./vector";
import { Circle } from "./circle";
import { Segment } from "./segment";
import { CollisionResult } from "./collision/collision-result";
export declare const Geom2Const: {
    PI: number;
    PI2: number;
};
/*****               Array                        *******/
/**
 * Randomly shuffle an array
 * https://stackoverflow.com/a/2450976/1293256
 * @param  {Array} array The array to shuffle
 * @return {String}      The first item in the shuffled array
 */
export declare function shuffle(array: Array<any>): any[];
/******              number                            *****/
export declare function sameSign(num1: number, num2: number): boolean;
export declare function pMod(a: number, n: number): number;
export declare function angleNormalize(a: number): number;
export declare function angleNormalizePI2(a: number): number;
export declare function angleDiff(angle1: number, angle2: number): number;
export declare function angleDiffPI2(angle1: number, angle2: number): number;
/******              Vector                            *****/
export declare function onSegment(s1: Vector, s2: Vector, v: Vector): boolean;
export declare function crossProduct3(v1: Vector, v2: Vector, v3: Vector): number;
export declare function triarea2(a: Vector, b: Vector, c: Vector): number;
export declare function sgn(x: number): number;
export declare function orientation(s: Segment, v: Vector): number;
export declare function intersectingVertex(v1: Vector, v2: Vector, v3: Vector, v4: Vector): Vector | null;
export declare function testSegmentSegment(s1p1: Vector, s1p2: Vector, s2p1: Vector, s2p2: Vector): boolean;
/******              Polygon                            *****/
/**
 * @param {Circle} a The first circle.
 * @param {Circle} b The second circle.
 * @param {TestResult} testResult Response object (optional) that will be populated if
 *   the circles intersects.
 * @return {boolean} true if the circles intersects, false if they don't.
 */
export declare function testCircleCircle(a: Circle, b: Circle, testResult?: CollisionResult): boolean;
/**
 * Check if a polygon and a circle collide.
 * @param {Polygon} polygon The polygon.
 * @param {Circle} circle The circle.
 * @param {TestResult} response Response object (optional) that will be populated if
 *   they interset.
 * @return {boolean} true if they intersects, false if they don't.
 */
export declare function testPolygonCircle(polygon: Polygon, circle: Circle, response: CollisionResult): boolean;
export declare function segmentHasPoint(v1: Vector, v2: Vector, p: Vector, tolerance?: number): boolean;
/**
 * Calculate distance and closest point between point and segment
 * @param pt the point
 * @param seg1 the start of segment
 * @param seg2 the end of segment
 * @param cp the closest point
 * @returns distance
 */
export declare function point2segment(pt: Vector, seg1: Vector, seg2: Vector, cp?: Vector): number;
export declare function point2polygon(pt: Vector, points: Array<Vector>, cp?: Vector): number;
export declare function lineLineIntersection(A: Vector, B: Vector, C: Vector, D: Vector): Vector;
export declare function clamp(value: number, min: number, max: number): number;
