import { Transform } from "./transform";
export declare class Vector {
    static ZERO: Vector;
    x: number;
    y: number;
    constructor(x?: number, y?: number);
    set(x: number | Vector, y?: number): this;
    addMul(v: Vector, scl: number): this;
    subMul(v: Vector, scl: number): this;
    scl(x: number, y?: number): this;
    add(v: Vector): this;
    translate(x: number, y: number): this;
    sub(v: Vector | Transform): this;
    perp(): this;
    rotate(angle: number, center?: Vector): this;
    angle(v: Vector): number;
    reverse(): this;
    dot(v: Vector): number;
    /**
     * @param v the other vector
     * @param ref reference vector
     * @return dot product of (this - ref), (v - ref)
     * result > 0 the angle between (this - ref), (v - ref) < 90
     * result < 0 the angle between (this - ref), (v - ref) > 90
     */
    dotRef(v: Vector, ref: Vector): number;
    /**
     * @param v
     * @return cross product
     */
    cross(v: Vector): number;
    /**
     * @param v the other vector
     * @param ref reference vector
     * @return cross product of (this - ref), (v - ref)
     * result < 0 if (v - ref) is on the right side of (this - ref)
     * result > 0 if (v - ref) is on the left side of (this - ref)
     */
    crossRef(v: Vector, ref: Vector): number;
    project(v: Vector): this;
    projectN(v: Vector): this;
    reflect(axis: Vector): this;
    reflectN(axis: Vector): this;
    normalize(): this;
    len2(): number;
    len(): number;
    setLen(len: number): this;
    clone(): Vector;
    dist2(v: Vector): number;
    dist(v: Vector): number;
    equalsTo(v: Vector): boolean;
    static lerp(start: Vector, end: Vector, t: number): Vector;
    toString(): string;
    angleTo(v: Vector): number;
}
